Toyz for Data Reduction and Analysis — Toyz 0.0.0 documentation

# Toyz for Data Reduction and Analysis

Contents:

Introduction to Toyz

- Overview
  - What is Toyz?
  - Possible Use Cases
  - Third Party Software
- Install
  - Requirements
  - Optional Requirements
  - Installing Toyz
    - Using pip
    - Installing from source
- Getting Started
  - First Time Setup
  - Running a Toyz Application
    - Remote server behind a firewall
    - Connecting to a Toyz Server Running on a local (or remote) network
    - Local Machine
  - Configuring a New Toyz Web Application
    - Change Password
    - Add New Users and Groups
    - Modify Permissions for Users and Groups
    - Configuraton Settings

# Coming Soon

I’m still finishing transfering Toyz from the old astropyp format. Some of the features that should be complete within the next week or two are workspaces, interactive Highcharts and Graph3d plots, and thorough documentation about how to incorporate your own scripts into a toyz application. Once that’s complete I will be pushing the distribution to PyPi so toyz can be installed via pip . Stay tuned.

# Indices and tables

- Index
- Module Index
- Search Page